@@ -14,8 +14,8 @@ def addition():
 		print(term.red(f'Incorrect! The correct answer was `{real_answer}`'))
 
 def subtraction():
-	a = random.randit(0,100) # Pick a number between 0 and 100
-	b = random.randit(0,100) #Pick aanother number between 0 and 100
+	a = random.randint(0,100) # Pick a number between 0 and 100
+	b = random.randint(0,100) #Pick aanother number between 0 and 100
 	real_answer = str(a - b)
 	user_answer = input(f"What is {a} - {b}? ")
 	if real_answer == user_answer:
@@ -24,8 +24,8 @@ def subtraction():
 		print(term.red(f'Incorrect! The correct answer was `{real_answer}`'))
 
 def multiplication():
-	a = random.randit(0,100) # Pick a number between 0 and 100
-	b = random.randit(0,100) # Pick a number between 0 and 100
+	a = random.randint(0,100) # Pick a number between 0 and 100
+	b = random.randint(0,100) # Pick a number between 0 and 100
 	real_answer = str(a *b)
 	user_answer = input(f"What is {a} * {b}? ")
 	if real_answer == user_answer:
@@ -34,8 +34,8 @@ def multiplication():
 		print('Incorrect')
 
 def division():
-	a = random.randit(0,100) # Pick a number between 0 and 100
-	b = random.randit(0,100) # Pick a number between 0 and 100
+	a = random.randint(0,100) # Pick a number between 0 and 100
+	b = random.randint(0,100) # Pick a number between 0 and 100
 	real_answer = str(a / b)
 	user_answer = input(f"What is {a} / {b}? ")
 	if real_answer == user_answer:
